@@ -319,7 +319,7 @@ def test_series_number_of_seasons_should_be_numeric(ia):
 
 def test_series_number_of_seasons_should_exclude_non_numeric_season_titles(ia):
     movie = ia.get_movie('0436992', info=['main'])      # Doctor Who
-    assert movie.get('number of seasons') == 11
+    assert movie.get('number of seasons') == 12
 
 
 def test_episode_original_air_date_should_be_a_date(ia):
@@ -359,7 +359,7 @@ def test_movie_genres_if_multiple_should_be_a_list_of_genre_names(ia):
 
 def test_movie_plot_outline_should_be_a_longer_text(ia):
     movie = ia.get_movie('0133093', info=['main'])      # Matrix
-    assert re.match('^Thomas A\. Anderson is a man .* human rebellion.$', movie.get('plot outline'))
+    assert re.match(r'^Thomas A\. Anderson is a man .* human rebellion.$', movie.get('plot outline'))
 
 
 def test_movie_plot_outline_none_should_be_excluded(ia):
@@ -467,6 +467,13 @@ def test_movie_colors_if_multiple_should_be_a_list_of_color_types(ia):
     assert movie.get('color info', []) == ['Black and White']
 
 
+def test_movie_cast_can_contain_notes(ia):
+    movie = ia.get_movie('0060666', info=['main'])      # Manos
+    diane_adelson = movie['cast'][2]
+    assert str(diane_adelson.currentRole) == 'Margaret'
+    assert diane_adelson.notes == '(as Diane Mahree)'
+
+
 def test_movie_colors_if_single_with_notes_should_include_notes(ia):
     movie = ia.get_movie('0060666', info=['main'])      # Manos
     assert movie.get('color info', []) == ['Color::(Eastmancolor)']
@@ -515,7 +522,15 @@ def test_movie_sound_mix_if_none_should_be_excluded(ia):
 def test_movie_certificates_should_be_a_list_of_certificates(ia):
     movie = ia.get_movie('1000252', info=['main'])      # Doctor Who - Blink
     assert movie.get('certificates', []) == [
-        'Brazil:12', 'United Kingdom:PG::(DVD rating)', 'United States:TV-PG'
+        'Australia:PG::(most episodes)',
+        'Brazil:12',
+        'Netherlands:9::(some episodes)',
+        'New Zealand:PG',
+        'Singapore:PG',
+        'South Africa:PG',
+        'United Kingdom:PG',
+        'United Kingdom:PG::(DVD rating)',
+        'United States:TV-PG'
     ]
 
 
@@ -529,11 +544,27 @@ def test_movie_cast_must_contain_items(ia):
     assert len(movie.get('cast', [])) > 20
 
 
+def test_movie_cast_must_be_in_plain_format(ia):
+    movie = ia.get_movie('0133093', info=['main'])      # Matrix
+    assert movie['cast'][0].data.get('name') == 'Keanu Reeves'
+
+
 def test_movie_misc_sections_must_contain_items(ia):
     movie = ia.get_movie('0133093', info=['main'])      # Matrix
     assert len(movie.get('casting department', [])) == 2
 
 
+def test_movie_misc_sections_must_be_in_plain_format(ia):
+    movie = ia.get_movie('0133093', info=['main'])      # Matrix
+    assert movie['casting department'][0].data.get('name') == 'Tim Littleton'
+
+
 def test_movie_companies_sections_must_contain_items(ia):
     movie = ia.get_movie('0133093', info=['main'])      # Matrix
     assert len(movie.get('special effects companies', [])) == 7
+
+
+def test_movie_box_office_should_be_a_dict(ia):
+    movie = ia.get_movie('0133093', info=['main'])      # Matrix
+    assert isinstance(movie.get('box office'), dict)
+    assert len(movie.get('box office', {})) == 3
