@@ -5,7 +5,12 @@ def test_movie_summary_should_be_some_text_with_author(ia):
     movie = ia.get_movie('0133093', info=['plot'])  # Matrix
     plots = movie.get('plot', [])
     assert 5 <= len(plots) <= 10
-    assert re.match('^Thomas A\. Anderson is a man .* rebellion\.::redcommander27$', plots[0])
+    kc_plot = ''
+    for plot in plots:
+        if plot.endswith('Kenneth Chisholm'):
+            kc_plot = plot
+            break
+    assert re.match(r'^A computer hacker .*controllers\.::Kenneth Chisholm$', kc_plot)
 
 
 def test_movie_summary_if_none_should_be_excluded(ia):
@@ -17,7 +22,7 @@ def test_movie_synopsis_should_be_some_text(ia):
     movie = ia.get_movie('0133093', info=['plot'])  # Matrix
     synopsis = movie.get('synopsis')
     assert len(synopsis) == 1
-    assert re.match('^The screen is filled with .* three Matrix movies\.$', synopsis[0])
+    assert re.match(r'^The screen fills with .* three Matrix movies\.$', synopsis[0])
 
 
 def test_movie_synopsis_if_none_should_be_excluded(ia):
