@@ -5,12 +5,18 @@ def test_person_headshot_should_be_an_image_link(ia):
     person = ia.get_person('0000206', info=['main'])    # Keanu Reeves
     assert re.match(r'^https?://.*\.jpg$', person['headshot'])
 
+def test_person_name_in_data_should_be_plain(ia):
+    person = ia.get_person('0000206', info=['main'])    # Keanu Reeves
+    assert person.data.get('name') == 'Keanu Reeves'
+
+def test_person_canonical_name(ia):
+    person = ia.get_person('0000206', info=['main'])    # Keanu Reeves
+    assert person.get('canonical name') == 'Reeves, Keanu'
 
 def test_person_headshot_if_none_should_be_excluded(ia):
     person = ia.get_person('0330139', info=['main'])    # Deni Gordon
     assert 'headshot' not in person
 
-
 def test_person_name_should_not_be_canonicalized(ia):
     person = ia.get_person('0000206', info=['main'])    # Keanu Reeves
     assert person.get('name') == 'Keanu Reeves'
